nvector._core.n_E_and_wa2R_EL — nvector 0.7.5 documentation

# nvector._core.n_E_and_wa2R_EL

`n_E_and_wa2R_EL`(n_E, wander_azimuth, R_Ee=None)

  Returns rotation matrix R_EL from n-vector and wander azimuth angle.

  Parameters
    n_E: 3 x n array

      n-vector [no unit] decomposed in E

    wander_azimuth: real scalar or array of length n

      Angle [rad] between L’s x-axis and north, positive about L’s z-axis.

    R_Ee3 x 3 array

      rotation matrix defining the axes of the coordinate frame E.

  Returns
    R_EL: 3 x 3 x n array

      The resulting rotation matrix. [no unit]

  See also

  `R_EL2n_E`, `R_EN2n_E`, `n_E2R_EN`

  Notes

  When wander_azimuth=0, we have that N=L. (See Table 2 in Gade (2010) for details)